@@ -1,18 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "34f6cb42d67338640855eb96097302e7b72fdd24",
-  "branchName": "release-client-5.16.x",
-  "buildTime": "2023-10-19 09:07:51 GMT",
-  "buildVersion": "468",
+  "commitId": "14a5a68bdf175acb02aada4e39937bd82677bfb6",
+  "branchName": "release-client-5.17.x",
+  "buildTime": "2024-02-22 09:45:36 GMT",
+  "buildVersion": "5.17.726",
   "css": [
-    "@zoom/client-scheduler/static/css/chunk-vendors.91880f7a.css",
-    "@zoom/client-scheduler/static/css/index.6fe66edc.css"
+    "@zoom/client-scheduler/static/css/chunk-vendors.5c990af7.css",
+    "@zoom/client-scheduler/static/css/index.1e453f20.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.974f1615.js",
-    "@zoom/client-scheduler/static/js/index.ce16da06.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.49875986.js",
+    "@zoom/client-scheduler/static/js/index.fb66f59e.js"
   ],
-  "key": "@zoom/client-scheduler"
+  "key": "clientSchedulerResource"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
